@@ -36,6 +36,7 @@ SEQUENCER_PROGRAM_ID = Pubkey.from_string(
 DEVNET_SEQUENCER_PROGRAM_ID = Pubkey.from_string(
     "FBngRHN4s5cmHagqy3Zd6xcK3zPJBeX5DixtHFbBhyCn"
 )
+VAULT_PROGRAM_ID = Pubkey.from_string("vAuLTsyrvSfZRuRB3XgvkPwNGgYSs9YRYymVebLKoxR")
 
 
 @dataclass
@@ -48,6 +49,7 @@ class Config:
     perp_markets: list[PerpMarketConfig]
     spot_markets: list[SpotMarketConfig]
     market_lookup_table: Pubkey
+    market_lookup_tables: list[Pubkey]
 
 
 configs = {
@@ -66,6 +68,9 @@ configs = {
         market_lookup_table=Pubkey.from_string(
             "FaMS3U4uBojvGn5FSDEPimddcXsCfwkKsFgMVVnDdxGb"
         ),
+        market_lookup_tables=[
+            Pubkey.from_string("FaMS3U4uBojvGn5FSDEPimddcXsCfwkKsFgMVVnDdxGb"),
+        ],
     ),
     "mainnet": Config(
         env="mainnet",
@@ -79,9 +84,14 @@ configs = {
         default_ws="wss://api.mainnet-beta.solana.com",
         perp_markets=mainnet_perp_market_configs,
         spot_markets=mainnet_spot_market_configs,
+        # deprecated, use market_lookup_tables instead
         market_lookup_table=Pubkey.from_string(
-            "D9cnvzswDikQDf53k4HpQ3KJ9y1Fv3HGGDFYMXnK5T6c"
+            "Fpys8GRa5RBWfyeN7AaDUwFGD1zkDCA4z3t4CJLV8dfL"
         ),
+        market_lookup_tables=[
+            Pubkey.from_string("Fpys8GRa5RBWfyeN7AaDUwFGD1zkDCA4z3t4CJLV8dfL"),
+            Pubkey.from_string("EiWSskK5HXnBTptiS5DH6gpAJRVNQ3cAhTKBGaiaysAb"),
+        ],
     ),
 }
 
@@ -168,7 +178,7 @@ async def find_all_market_and_oracles(
         json=perp_request,
         headers={"content-encoding": "gzip"},
     )
-    resp = await asyncio.wait_for(post, timeout=10)
+    resp = await asyncio.wait_for(post, timeout=120)
     parsed_resp = jsonrpcclient.parse(resp.json())
 
     if isinstance(parsed_resp, jsonrpcclient.Error):
@@ -200,7 +210,7 @@ async def find_all_market_and_oracles(
         json=spot_request,
         headers={"content-encoding": "gzip"},
     )
-    resp = await asyncio.wait_for(post, timeout=10)
+    resp = await asyncio.wait_for(post, timeout=120)
     parsed_resp = jsonrpcclient.parse(resp.json())
 
     if isinstance(parsed_resp, jsonrpcclient.Error):
