@@ -1,35 +1,51 @@
-from copy import deepcopy
 import math
 import time
+from copy import deepcopy
+from dataclasses import fields
+from solders.pubkey import Pubkey
 from typing import Optional, Tuple
 
 from driftpy.constants.numeric_constants import (
     AMM_TIMES_PEG_TO_QUOTE_PRECISION_RATIO,
-)
-from driftpy.constants.numeric_constants import (
+    AMM_TO_QUOTE_PRECISION_RATIO,
+    BID_ASK_SPREAD_PRECISION,
     DEFAULT_REVENUE_SINCE_LAST_FUNDING_SPREAD_RETREAT,
+    FUNDING_RATE_BUFFER,
+    PEG_PRECISION,
+    PERCENTAGE_PRECISION,
+    PRICE_DIV_PEG,
+    PRICE_PRECISION,
+    QUOTE_PRECISION,
 )
-from driftpy.constants.numeric_constants import AMM_TO_QUOTE_PRECISION_RATIO
-from driftpy.constants.numeric_constants import BID_ASK_SPREAD_PRECISION
-from driftpy.constants.numeric_constants import FUNDING_RATE_BUFFER
-from driftpy.constants.numeric_constants import PEG_PRECISION
-from driftpy.constants.numeric_constants import PERCENTAGE_PRECISION
-from driftpy.constants.numeric_constants import PRICE_DIV_PEG
-from driftpy.constants.numeric_constants import PRICE_PRECISION
-from driftpy.constants.numeric_constants import QUOTE_PRECISION
 from driftpy.math.oracles import calculate_live_oracle_std
-from driftpy.math.repeg import calculate_adjust_k_cost
-from driftpy.math.repeg import calculate_budgeted_peg
-from driftpy.math.repeg import calculate_optimal_peg_and_budget
-from driftpy.math.repeg import calculate_repeg_cost
-from driftpy.math.utils import clamp_num
-from driftpy.math.utils import sig_num
-from driftpy.types import AMM
-from driftpy.types import AssetType
-from driftpy.types import is_variant
-from driftpy.types import OraclePriceData
-from driftpy.types import PositionDirection
-from driftpy.types import SwapDirection
+from driftpy.math.repeg import (
+    calculate_adjust_k_cost,
+    calculate_budgeted_peg,
+    calculate_optimal_peg_and_budget,
+    calculate_repeg_cost,
+)
+from driftpy.math.utils import clamp_num, sig_num
+from driftpy.types import (
+    AMM,
+    AssetType,
+    OraclePriceData,
+    PositionDirection,
+    SwapDirection,
+    is_variant,
+)
+
+
+def deepcopy_amm(amm: AMM) -> AMM:
+    field_values = {}
+    field_names = {field.name for field in fields(AMM)}
+    for field in amm.__dataclass_fields__.values():
+        value = getattr(amm, field.name)
+        if isinstance(value, Pubkey):
+            field_values[field.name] = value
+        elif field.name in field_names:
+            field_values[field.name] = deepcopy(value)
+    copied = AMM(**field_values)
+    return copied
 
 
 def calculate_vol_spread_bn(
@@ -43,11 +59,11 @@ def calculate_vol_spread_bn(
 ):
     market_avg_std_pct = (
         ((mark_std + oracle_std) * PERCENTAGE_PRECISION) // reserve_price
-    ) // 2
+    ) // 4
     vol_spread = max(last_oracle_conf_pct, market_avg_std_pct // 2)
 
     clamp_min = PERCENTAGE_PRECISION // 100
-    clamp_max = (PERCENTAGE_PRECISION * 16) // 10
+    clamp_max = PERCENTAGE_PRECISION
 
     long_vol_spread_factor = clamp_num(
         (long_intensity * PERCENTAGE_PRECISION) // max(1, volume_24h),
@@ -63,7 +79,7 @@ def calculate_vol_spread_bn(
     conf_component = last_oracle_conf_pct
 
     if last_oracle_conf_pct <= PRICE_PRECISION // 400:
-        conf_component = last_oracle_conf_pct // 10
+        conf_component = last_oracle_conf_pct // 20
 
     long_vol_spread = max(
         conf_component, (vol_spread * long_vol_spread_factor) // PERCENTAGE_PRECISION
@@ -235,6 +251,7 @@ def calculate_spread_bn(
     long_intensity: int,
     short_intensity: int,
     volume24H: int,
+    amm_inventory_spread_adjustment: int = 0,
     return_terms: bool = False,
 ):
     assert isinstance(base_spread, int)
@@ -257,6 +274,8 @@ def calculate_spread_bn(
         "half_revenue_retreat_amount": 0,
         "long_spread_w_rev_retreat": 0,
         "short_spread_w_rev_retreat": 0,
+        "long_spread_w_offset_shrink": 0,
+        "short_spread_w_offset_shrink": 0,
         "total_spread": 0,
         "long_spread": 0,
         "short_spread": 0,
@@ -292,10 +311,17 @@ def calculate_spread_bn(
     spread_terms["long_spread_w_ps"] = long_spread
     spread_terms["short_spread_w_ps"] = short_spread
 
-    max_target_spread = float(
-        math.floor(max(max_spread, abs(last_oracle_reserve_price_spread_pct)))
+    max_spread_baseline = min(
+        max(
+            abs(last_oracle_reserve_price_spread_pct),
+            last_oracle_conf_pct * 2,
+            max(mark_std, oracle_std) * PERCENTAGE_PRECISION // reserve_price,
+        ),
+        BID_ASK_SPREAD_PRECISION,
     )
 
+    max_target_spread = float(math.floor(max(max_spread, max_spread_baseline)))
+
     inventory_spread_scale = calculate_inventory_scale(
         base_asset_amount_with_amm,
         base_asset_reserve,
@@ -382,6 +408,30 @@ def calculate_spread_bn(
     spread_terms["long_spread_w_rev_retreat"] = long_spread
     spread_terms["short_spread_w_rev_retreat"] = short_spread
 
+    if amm_inventory_spread_adjustment < 0:
+        adjustment = abs(amm_inventory_spread_adjustment)
+
+        shrunk_long = max(1, long_spread - math.floor((long_spread * adjustment) / 100))
+        shrunk_short = max(
+            1, short_spread - math.floor((short_spread * adjustment) / 100)
+        )
+
+        long_spread = max(long_vol_spread, shrunk_long)
+        short_spread = max(short_vol_spread, shrunk_short)
+    elif amm_inventory_spread_adjustment > 0:
+        adjustment = amm_inventory_spread_adjustment
+
+        grown_long = max(1, long_spread + math.ceil((long_spread * adjustment) / 100))
+        grown_short = max(
+            1, short_spread + math.ceil((short_spread * adjustment) / 100)
+        )
+
+        long_spread = max(long_vol_spread, grown_long)
+        short_spread = max(short_vol_spread, grown_short)
+
+    spread_terms["long_spread_w_offset_shrink"] = long_spread
+    spread_terms["short_spread_w_offset_shrink"] = short_spread
+
     total_spread = long_spread + short_spread
     if total_spread > max_target_spread:
         if long_spread > short_spread:
@@ -445,11 +495,24 @@ def calculate_spread(
         amm.long_intensity_volume,
         amm.short_intensity_volume,
         amm.volume24h,
+        amm.amm_inventory_spread_adjustment,
     )
 
     long_spread = spreads[0]
     short_spread = spreads[1]
 
+    amm_spread_adjustment = amm.amm_spread_adjustment
+    if amm_spread_adjustment > 0:
+        long_spread = max(long_spread + (long_spread * amm_spread_adjustment) / 100, 1)
+        short_spread = max(
+            short_spread + (short_spread * amm_spread_adjustment) / 100, 1
+        )
+    elif amm_spread_adjustment < 0:
+        long_spread = max(long_spread - (long_spread * -amm_spread_adjustment) / 100, 1)
+        short_spread = max(
+            short_spread - (short_spread * -amm_spread_adjustment) / 100, 1
+        )
+
     return long_spread, short_spread
 
 
@@ -505,8 +568,8 @@ def calculate_price(
 
 
 def calculate_swap_output(
-    swap_amount: int,
     input_asset_reserve: int,
+    swap_amount: int,
     swap_direction: SwapDirection,
     invariant: int,
 ):
@@ -622,7 +685,7 @@ def calculate_spread_reserves(
 
     if amm.curve_update_intensity > 100:
         max_offset = max(
-            amm.max_spread // 5,
+            amm.max_spread // 2,
             (PERCENTAGE_PRECISION // 10_000) * (amm.curve_update_intensity - 100),
         )
 
@@ -654,11 +717,11 @@ def calculate_spread_reserves(
     )
 
     ask_reserves = calculate_spread_reserve(
-        long_spread + reference_price_offset, PositionDirection.Long(), amm
+        int(long_spread) + reference_price_offset, PositionDirection.Long(), amm
     )
 
     bid_reserves = calculate_spread_reserve(
-        -short_spread + reference_price_offset, PositionDirection.Short(), amm
+        -int(short_spread) + reference_price_offset, PositionDirection.Short(), amm
     )
 
     return bid_reserves, ask_reserves
@@ -707,7 +770,7 @@ def calculate_updated_amm(amm: AMM, oracle_price_data: OraclePriceData) -> AMM:
     if amm.curve_update_intensity == 0 or oracle_price_data is None:
         return amm
 
-    new_amm = deepcopy(amm)
+    new_amm = deepcopy_amm(amm)
     (prepeg_cost, p_k_numer, p_k_denom, new_peg) = calculate_new_amm(
         amm, oracle_price_data
     )
@@ -768,7 +831,7 @@ def calculate_new_amm(amm: AMM, oracle_price_data: OraclePriceData):
 
         pre_peg_cost = budget + abs(deficit_makeup)
 
-        new_amm = deepcopy(amm)
+        new_amm = deepcopy_amm(amm)
 
         new_amm.base_asset_reserve = (
             new_amm.base_asset_reserve * p_k_numer
